# su6-plugin-demo

[![PyPI - Version](https://img.shields.io/pypi/v/su6-plugin-demo.svg)](https://pypi.org/project/su6-plugin-demo)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/su6-plugin-demo.svg)](https://pypi.org/project/su6-plugin-demo)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)  
[![su6 checks](https://github.com/robinvandernoord/su6-plugin-demo/actions/workflows/su6.yml/badge.svg)](https://github.com/robinvandernoord/su6-plugin-demo/actions)
![coverage.svg](coverage.svg)
-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install su6 su6-plugin-demo
```

## License

`su6-plugin-demo` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
